# tonkin

<!-- Remember to change the URL from pytemplate to the name of your project -->
![Tests](https://github.com/HWRacing/tonkin/actions/workflows/tests.yml/badge.svg)

This is a library for reading .dat files generated by EcoCAL with the EV2274A.
